Learn R Programming

NuPoP (version 1.22.0)

readNuPoP: R function for plotting the predicted nucleosome positioning map and nucleosome occupancy map

Description

This function reads in the prediction results generated by predNuPoP for specified region.

Usage

readNuPoP(file,startPos,endPos)

Arguments

file
the prediction output file name from predNuPoP function.
startPos
the start position in the DNA sequence for prediction results plotting.
endPos
the end position in the DNA sequence for prediction results plotting.

Examples

Run this code
library(NuPoP)
predNuPoP(system.file("extdata", "test.seq", package="NuPoP"),species=7,model=4)

## the prediction results are stored in the current working directory
## the user should replace "system.file("extdata","test.seq_Prediction4.txt",package="NuPoP")"
## by the actual path and file name generated from prediction.

temp=readNuPoP(system.file("extdata","test.seq_Prediction4.txt",package="NuPoP"),startPos=1,endPos=5000)

Run the code above in your browser using DataLab